# 進捗状況: sgmap

## 機能している部分

### コア機能

- [x] AWS API からセキュリティグループ情報を取得する機能
- [x] VPC ID でフィルタリングする機能
- [x] セキュリティグループ ID でフィルタリングする機能
- [x] セキュリティグループの接続関係を分析する機能
- [x] mermaid 記法でのフローチャート出力機能
- [x] JSON 形式での出力機能

### CLI インターフェース

- [x] 必須パラメータ（VPC ID）の処理
- [x] オプショナルパラメータ（セキュリティグループ ID）の処理
- [x] 出力形式の選択オプション（--json）
- [x] 基本的なエラーハンドリング

### プロジェクト構造

- [x] モジュール構造の設計
- [x] パッケージ設定ファイル（setup.py）の作成
- [x] 依存関係の定義（requirements.txt）
- [x] README の作成
- [x] memory-bank の初期化
- [x] ライブラリとしての利用を可能にする公開 API の提供

## 構築すべき残りの部分

### テスト

- [ ] ユニットテストの実装
- [ ] インテグレーションテストの実装
- [ ] テストカバレッジの測定
- [ ] モックを使用した AWS API 呼び出しのテスト

### ドキュメント

- [ ] インストールガイドの詳細化
- [ ] 使用例の追加
- [ ] トラブルシューティングガイドの作成
- [ ] API 参照ドキュメントの作成

### 機能拡張

- [ ] 複数の VPC を一度に分析する機能
- [ ] 追加の出力形式（SVG、PNG、DOT など）
- [ ] 追加のフィルタリングオプション（タグ、名前など）
- [ ] AWS Organizations との統合（複数アカウントの分析）
- [ ] 時間経過による変更の追跡機能

### CI/CD

- [ ] GitHub Actions の設定
- [ ] 自動テストの実行
- [ ] コードカバレッジの測定
- [ ] PyPI への自動デプロイ

### パッケージング

- [x] PyPI への公開準備
- [x] バージョニング戦略の確立（タグのバージョンがそのまま PyPI のバージョンになるよう設定）
- [x] リリースプロセスの確立（GitHub Actions によるタグベースの自動リリース）
- [x] バージョニング問題の修正（`pyproject.toml`の設定を修正し、タグのバージョンがそのまま PyPI のバージョンになるように設定、余分なサフィックスが付かないように設定）

## 現在の状態

現在、sgmap の基本的な機能実装が完了しています。コアモジュールと CLI インターフェースが実装され、指定した VPC 内のセキュリティグループの接続関係を mermaid 記法または JSON 形式で出力できます。

プロジェクトの基本構造が整い、パッケージとしてインストールできる状態になっています。README も作成され、基本的な使用方法が記載されています。

また、ライブラリとしての利用も可能になり、Python コード内から直接 sgmap の機能を利用できるようになりました。バージョニング戦略も確立され、タグのバージョンがそのまま PyPI のパッケージバージョンとして使用されるように設定されています。`pyproject.toml`の設定を修正し、タグのバージョンがそのまま使用され、余分なサフィックス（`.post1.dev0`など）が付かないようになりました。

mermaid 図の視覚的な改善として、inbound と outbound の線の色を区別するように修正しました。inbound 接続は薄いグレー（#aaaaaa）、outbound 接続は濃いグレー（#777777）で表示されるようになり、接続の方向が視覚的に分かりやすくなりました。また、mermaid の構文エラーを解消するために、色の指定方法を linkStyle を使用した実装に変更し、各矢印のインデックスを正確に追跡するようにしました。

## 既知の問題

1. **テストの不足**: 現在、テストが実装されていないため、機能の正確性が保証されていません。
2. **エラーハンドリングの不足**: より詳細なエラーメッセージと例外処理が必要です。
3. **大規模環境での未検証**: 多数のセキュリティグループがある大規模環境でのパフォーマンスが未検証です。
4. **クロスアカウント分析の未対応**: 現在、単一の AWS アカウント内のセキュリティグループのみを分析できます。
5. **出力形式の制限**: 現在、mermaid 記法と JSON 形式のみをサポートしています。

## 次のマイルストーン

### マイルストーン 1: テストとドキュメントの充実

- ユニットテストの実装
- インテグレーションテストの実装
- ドキュメントの拡充

### マイルストーン 2: 機能拡張

- 追加の出力形式のサポート
- 追加のフィルタリングオプションの追加
- パフォーマンスの最適化

### マイルストーン 3: CI/CD とリリース

- CI/CD パイプラインの設定
- PyPI への公開
- バージョン 1.0 のリリース
