# システムパターン: sgmap

## システムアーキテクチャ

sgmap は、モジュール化された Python アプリケーションとして設計されています。主要なコンポーネントは以下の通りです：

```
sgmap/
├── sgmap/
│   ├── __init__.py    # パッケージ初期化
│   ├── cli.py         # コマンドラインインターフェース
│   └── core.py        # コア機能
├── tests/             # テストコード
├── setup.py           # パッケージ設定
└── requirements.txt   # 依存関係
```

## 主要コンポーネントと責任

### コアモジュール (core.py)

コアモジュールは、アプリケーションの主要なビジネスロジックを担当します：

1. **データ取得**: AWS API を使用してセキュリティグループ情報を取得
2. **データ分析**: セキュリティグループ間の接続関係を分析
3. **出力生成**: mermaid 記法や JSON 形式での出力を生成

主要な関数：

- `get_security_groups()`: AWS API からセキュリティグループ情報を取得
- `analyze_security_group_connections()`: セキュリティグループの接続関係を分析
- `generate_mermaid_diagram()`: mermaid 記法のダイアグラムを生成
- `generate_json_output()`: JSON 形式の出力を生成

### CLI モジュール (cli.py)

CLI モジュールは、ユーザーとのインターフェースを担当します：

1. **コマンドライン引数の解析**: Click ライブラリを使用してコマンドライン引数を解析
2. **ユーザー入力の検証**: 入力値の検証とエラーハンドリング
3. **コア機能の呼び出し**: 適切なパラメータでコア機能を呼び出し
4. **結果の出力**: 生成された出力をコンソールに表示

主要な関数：

- `main()`: CLI のエントリーポイント

## 設計パターン

### モジュール分割パターン

アプリケーションは、責任に基づいて明確に分割されたモジュールで構成されています：

- **コア機能**: ビジネスロジックと出力生成
- **CLI**: ユーザーインターフェースとパラメータ処理

この分割により、各モジュールは単一の責任を持ち、テストや保守が容易になります。

### コマンドパターン

Click ライブラリを使用して、コマンドパターンを実装しています。これにより、コマンドラインオプションの定義と処理が簡潔になり、将来的なコマンドの追加も容易になります。

### ファサードパターン

コアモジュールは、AWS API の複雑さを隠蔽し、シンプルなインターフェースを提供するファサードとして機能します。これにより、CLI モジュールは AWS API の詳細を知る必要がなく、高レベルの関数を呼び出すだけで済みます。

## データフロー

1. ユーザーがコマンドラインからパラメータを指定して実行
2. CLI モジュールがパラメータを解析して検証
3. コアモジュールが AWS API を呼び出してセキュリティグループ情報を取得
4. コアモジュールがセキュリティグループの接続関係を分析
5. コアモジュールが指定された形式（mermaid または JSON）で出力を生成
6. CLI モジュールが生成された出力をコンソールに表示

## エラーハンドリング

エラーハンドリングは、以下の原則に基づいて実装されています：

1. **早期検出**: パラメータの検証など、できるだけ早い段階でエラーを検出
2. **明確なメッセージ**: ユーザーが問題を理解し解決できるよう、明確なエラーメッセージを提供
3. **適切な終了コード**: エラーが発生した場合は非ゼロの終了コードを返し、スクリプトやパイプラインでの使用を容易に

## 拡張性

将来的な拡張を考慮して、以下の点に注意して設計されています：

1. **モジュール化**: 新機能の追加が容易なモジュール構造
2. **出力形式の抽象化**: 新しい出力形式の追加が容易な設計
3. **パラメータの拡張性**: 新しいオプションやフィルタの追加が容易な CLI 設計
